MADCUBApy
=========

|PyPI Status| |Documentation Status|

Package to read MADCUBA product like maps or spectra alongside their history files.

This package is in its first test versions and should not be used in its current state.

.. |PyPI Status| image:: https://img.shields.io/pypi/v/madcubapy
    :target: https://pypi.org/project/madcubapy
    :alt: PyPI Status

.. |Documentation Status| image:: https://img.shields.io/readthedocs/madcubapy/latest.svg?logo=read%20the%20docs&logoColor=white&label=Docs
    :target: https://madcubapy.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status
